@@ -594,7 +594,7 @@ class TestValidationErrorMessages(TestCase):
         message = self.message_for(instance=["foo", "bar"], schema=schema)
         self.assertIn(
             message,
-            "Unevaluated items are not allowed ('foo', 'bar' were unexpected)",
+            "Unevaluated items are not allowed ('bar', 'foo' were unexpected)",
         )
 
     def test_unevaluated_properties(self):
@@ -609,7 +609,7 @@ class TestValidationErrorMessages(TestCase):
         self.assertEqual(
             message,
             "Unevaluated properties are not allowed "
-            "('foo', 'bar' were unexpected)",
+            "('bar', 'foo' were unexpected)",
         )
 
 
@@ -1411,7 +1411,7 @@ class MetaSchemaTestsMixin(object):
         """
         Technically, all the spec says is they SHOULD have elements, not MUST.
 
-        See https://github.com/Julian/jsonschema/issues/529.
+        See #529.
         """
         self.Validator.check_schema({"enum": []})
 
@@ -1419,7 +1419,7 @@ class MetaSchemaTestsMixin(object):
         """
         Technically, all the spec says is they SHOULD be unique, not MUST.
 
-        See https://github.com/Julian/jsonschema/issues/529.
+        See #529.
         """
         self.Validator.check_schema({"enum": [12, 12]})
 
@@ -1552,7 +1552,7 @@ class ValidatorTestMixin(MetaSchemaTestsMixin, object):
         """
         A tuple instance properly formats validation errors for uniqueItems.
 
-        See https://github.com/Julian/jsonschema/pull/224
+        See #224
         """
         TupleValidator = validators.extend(
             self.Validator,
